package org.aohe;

import java.io.IOException;

import lombok.extern.slf4j.Slf4j;
import org.aohe.core.sane.utils.SaneSessionUtils;
import org.aohe.core.swing.LogWindow;
import org.aohe.core.utils.CommandUtils;
import org.aohe.core.utils.SystemUtils;
import org.aohe.core.web.SocketFactory;

import javax.swing.*;

@Slf4j
public class Main {

    public static void main(String[] args) throws IOException, InterruptedException {
        log.info(" 当前系统类型： {}", SystemUtils.getOsName());
        try {
            //设置窗口主题
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } catch (ClassNotFoundException | InstantiationException | IllegalAccessException |
                 UnsupportedLookAndFeelException e) {
            throw new RuntimeException(e);
        }
        //初始化其他资源
        init();
        SwingUtilities.invokeLater(() -> new LogWindow().setVisible(true));

    }

    public static void init(){
        log.info("程序初始化开始...");
        CommandUtils.initSanedSocket();
        stopGracefully();
        log.info("Hook注册成功...");
    }


    public static void stopGracefully() {
        log.info("优雅退出Hook注册");
        //优雅退出，在程序停止时，销毁关键资源占用
        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            log.info("开始资源释放");
            //释放sane资源
            SaneSessionUtils.resource();
            SocketFactory.stop();
            log.info("socket 服务已关闭 ");
        }));
    }
}