package org.aohe.core.swing;

import lombok.extern.slf4j.Slf4j;
import org.aohe.core.web.SocketFactory;

import javax.swing.*;
import java.awt.*;
import java.net.UnknownHostException;

@Slf4j
public class LogWindow extends JFrame {

    private static boolean serviceStatus = false;

    private static JTextArea logTextArea;

    public LogWindow() {
        // 设置窗口标题
        setTitle("扫描仪控制器");

        // 设置默认的关闭操作
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        // 设置窗口大小
        setSize(400, 300);

        // 居中显示窗口
        setLocationRelativeTo(null);

        // 初始化UI组件
        initializeComponents();
    }

    private void initializeComponents() {
        // 在这里添加你的组件初始化代码
        // 创建一个JTextArea用于显示日志
        logTextArea = new JTextArea();
        logTextArea.setEditable(false); // 设置为不可编辑

        // 将JTextArea放入JScrollPane中以支持滚动
        JScrollPane scrollPane = new JScrollPane(logTextArea);

        // 将JScrollPane添加到窗口中
        getContentPane().add(scrollPane, BorderLayout.CENTER);

        JLabel textField = new JLabel();
        textField.setText("服务状态：" + getServiceStatus());

        JPanel bottomPanel = new JPanel();

        // 示例：添加一个按钮，点击时向文本区域添加日志信息
        JButton startButton = new JButton("开始");
        JButton stopButton = new JButton("停止");
        stopButton.setEnabled(false);
        startButton.addActionListener(e -> {
            startButton.setEnabled(false);
            stopButton.setEnabled(true);
            initSocket();
            setView("服务已打开...");
            serviceStatus = true;
            textField.setText("服务状态：" + getServiceStatus());
        });
        stopButton.addActionListener(e -> {
            stopButton.setEnabled(false);
            logTextArea.append("关闭服务中...\n");
            new Thread(() -> {
                //开个新线程关闭，防止主UI线程卡死
                stopSocket();
                serviceStatus = false;
                startButton.setEnabled(true);
                textField.setText("服务状态：" + getServiceStatus());
            }).start();

        });

        bottomPanel.add(startButton, BorderLayout.CENTER);
        bottomPanel.add(stopButton, BorderLayout.CENTER);
        getContentPane().add(textField, BorderLayout.NORTH);

        getContentPane().add(bottomPanel, BorderLayout.SOUTH);

    }

    public static void main(String[] args) {
        log.info("服务启动中...");
        try {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        } catch (UnsupportedLookAndFeelException e) {
            System.err.println("UnsupportedLookAndFeelException: " + e.getMessage());
        } catch (ClassNotFoundException | InstantiationException | IllegalAccessException e) {
            log.error("出错了 " , e);
            throw new RuntimeException(e);
        }
        SwingUtilities.invokeLater(() -> new LogWindow().setVisible(true));
    }

    public static String getServiceStatus() {
        if (serviceStatus){
            return "已启动";
        }
        return "未启动";
    }

    public static void initSocket() {
        SocketFactory.start();
    }

    public void stopSocket() {
        try {
            SocketFactory.stop();
            Thread.sleep(1000);
            setView("服务关闭");
            log.info("服务关闭");
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

    public static void setView(String msg){
        if(logTextArea != null){
            logTextArea.append(msg +"\n");
        }
    }
}

