package org.aohe.core.web;

import lombok.Getter;
import lombok.extern.slf4j.Slf4j;

import java.net.UnknownHostException;

/**
 * Socket 工厂
 */
@Slf4j
public class SocketFactory {

    /**
     * -- GETTER --
     *  get 方法
     *
     * @return
     */
    @Getter
    private static SocketServer socketServer;

    private static SocketFactory instance ;

    private SocketFactory() {
    }


    /**
     * 获取Socket客户端
     * @return socketServer
     */
    private static SocketServer getSocket(){
        try {
            log.info("Create Socket ...");
            socketServer = new SocketServer(8997);
        } catch (UnknownHostException e) {
            throw new RuntimeException(e);
        }
        return socketServer;
    }

    /**
     * 启动socket服务
     */
    public static void start(){
        getSocket().start();
        log.info("socket 已启动");
    }

    /**
     * 停止socket服务
     */
    public static void stop(){
        try {
            SocketServer server = getSocketServer();
            if(server != null){
                server.stop();
            }
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

}
