package org.aohe.core.web;

import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;
import java.net.InetSocketAddress;
import java.net.UnknownHostException;
import org.aohe.core.result.R;
import org.aohe.core.sane.SaneOperational;

import org.aohe.core.sane.utils.SaneSessionUtils;
import org.aohe.core.utils.SystemUtils;
import org.java_websocket.WebSocket;
import org.java_websocket.handshake.ClientHandshake;
import org.java_websocket.server.WebSocketServer;

@Slf4j
public class SocketServer extends WebSocketServer {

    public SocketServer(int port) throws UnknownHostException {
        super(new InetSocketAddress(port));
    }

    public SocketServer(int port, String path) throws UnknownHostException {
        super(new InetSocketAddress(port));
    }

    public SocketServer(InetSocketAddress address) {
        super(address);
    }

    @Override
    public void onOpen(WebSocket conn, ClientHandshake handshake) {
        conn.send("Welcome to the scan-server!"); // This method sends a message to the new client
        log.info("client is open ,client system is: {}", SystemUtils.getOsName());
    }

    @Override
    public void onClose(WebSocket conn, int code, String reason, boolean remote) {
        log.info("client is closed , client system is : {}", SystemUtils.getOsName());
        //这里执行关闭连接
        conn.close();
        SaneSessionUtils.resource();
    }

    @Override
    public void onMessage(WebSocket conn, String message) {
        log.info("User send Data: \n{}", message);
        String result;
        if(!JSONUtil.isTypeJSON(message)){
            result = R.fail("Illegal parameters, not of json type").toJsonStr();
        }else {
            result = SaneOperational.selectOperational(message);
        }
        log.info("Return data: \n {}", result);
        conn.send(result);
    }

    @Override
    public void onError(WebSocket conn, Exception ex) {
        log.error("error :{}", ex.getMessage(), ex);
        if (conn != null) {
            //绑定不到就退出
            //System.exit(0);
            // some errors like port binding failed may not be assignable to a specific
            // websocket
            log.error( "System error ", ex );
        }

    }

    @Override
    public void onStart() {
        log.info("Server started!");
        setConnectionLostTimeout(0);
        setConnectionLostTimeout(100);

    }
}

